@@ -1,11 +1,12 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-dbus-0.10.10/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: dbus
-version: 0.10.5
-id: dbus-0.10.5-3dd5b02bf50a30c5216760b87aea8723
+version: 0.10.10
+id: dbus-0.10.10-83cdbfe2263338f5d8a1674f1592077e
 
 license: GPL-3
 copyright:
-maintainer: John Millikin <jmillikin@gmail.com>
+maintainer: John Millikin <john@john-millikin.com>
 stability: experimental
 homepage: https://john-millikin.com/software/haskell-dbus/
 package-url:
@@ -61,38 +62,38 @@ description: D-Bus is a simple, message-based protocol for inter-process
              >org.freedesktop.secrets
              >org.gnome.ScreenSaver
 category: Network, Desktop
-author: John Millikin <jmillikin@gmail.com>
+author: John Millikin <john@john-millikin.com>
 pkgpath: x11/hs-dbus
 exposed: True
 exposed-modules: DBus DBus.Client DBus.Introspection DBus.Socket
                  DBus.Transport
 hidden-modules: DBus.Address DBus.Message DBus.Types DBus.Wire
 trusted: False
-import-dirs: /usr/local/lib/ghc/dbus-0.10.5
-library-dirs: /usr/local/lib/ghc/dbus-0.10.5
-hs-libraries: HSdbus-0.10.5
+import-dirs: /usr/local/lib/ghc/dbus-0.10.10
+library-dirs: /usr/local/lib/ghc/dbus-0.10.10
+hs-libraries: HSdbus-0.10.10
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
-         cereal-0.3.5.2-a9ff0516a3b8fef3d6dca329fe564618
-         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
-         libxml-sax-0.7.4-5f061f92ccfe62bb12f7a05b9ee352ff
-         network-2.4.1.2-d8af12af3edec327865681988e18696b
-         parsec-3.1.3-83475a11f2461aa1a11fb4b6a9cf137c
-         random-1.0.1.1-49dee13e6169a73481e9624e99220b78
-         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
-         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
-         unix-2.6.0.1-eff76fcbf6509b60a4df5e8289027c63
-         vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
-         xml-types-0.3.4-b39fd38cbbdcc8921c8e2439b41c614c
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         cereal-0.4.1.0-9d42a4c31bc1d35f6a410f5e79e67215
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         libxml-sax-0.7.5-590dd24d99e22068cb2f44fcb349f590
+         network-2.4.2.3-878f8bfcc369ed62265df39b168036b0
+         parsec-3.1.5-7f6674da593b27c3fdd904274a0dcd1e
+         random-1.0.1.1-18033e0e7d0ae09dc4f8adbdce56b966
+         text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
+         transformers-0.3.0.0-6458c21515cab7c1cf21e53141557a1c
+         unix-2.7.0.1-49291e6beb52ca8844af5af8283d8383
+         vector-0.10.9.1-1010d9fb05d5cbdd0bbbccafb8c8b174
+         xml-types-0.3.6-fc8bb242aedf216e5a0c41a863029711
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-dbus-0.10.5/html/dbus.haddock
-haddock-html: /usr/local/share/doc/hs-dbus-0.10.5/html
+haddock-interfaces: /usr/local/share/doc/hs-dbus-0.10.10/html/dbus.haddock
+haddock-html: /usr/local/share/doc/hs-dbus-0.10.10/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
